@@ -24,10 +24,10 @@ from osc_lib import exceptions
 from osc_lib.i18n import _
 from prettytable import PrettyTable
 
-from tripleoclient import command
-from tripleoclient import constants
+from osc_lib.command import command
 from tripleoclient import utils as oooutils
 from tripleoclient.workflows import deployment
+from tripleoclient import constants
 
 from validations_libs import constants as v_consts
 from validations_libs import utils as v_utils
@@ -212,10 +212,9 @@ class TripleOValidatorList(command.Lister):
         try:
             v_consts.DEFAULT_VALIDATIONS_BASEDIR = constants.\
                 DEFAULT_VALIDATIONS_BASEDIR
-            actions = ValidationActions(
-                validation_path=constants.ANSIBLE_VALIDATION_DIR
-            )
-            return actions.list_validations(parsed_args.group)
+            actions = ValidationActions(constants.ANSIBLE_VALIDATION_DIR,
+                                        parsed_args.group)
+            return actions.list_validations()
         except Exception as e:
             raise RuntimeError(_("Validations listing finished with errors\n"
                                  "Output: {}").format(e))
@@ -267,13 +266,6 @@ class TripleOValidatorRun(command.Command):
             )
         )
 
-        parser.add_argument(
-            '--python-interpreter',
-            action='store',
-            default="/usr/libexec/platform-python",
-            help=_("Python interpreter for Ansible execution. ")
-        )
-
         extra_vars_group = parser.add_mutually_exclusive_group(required=False)
 
         extra_vars_group.add_argument(
@@ -300,7 +292,7 @@ class TripleOValidatorRun(command.Command):
             )
         )
 
-        parser.add_argument(
+        extra_vars_group.add_argument(
             '--extra-env-vars',
             metavar="key1=<val1>[,key2=val2 --extra-env-vars key3=<val3>]",
             action=parseractions.MultiKeyValueAction,
@@ -360,7 +352,7 @@ class TripleOValidatorRun(command.Command):
                       "inventory or use authentication."))
         else:
             if plan:
-                status = deployment.get_deployment_status(clients, plan=plan)
+                status = deployment.get_deployment_status(clients, plan)
                 if not status or status in NO_VALIDATION_STATE:
                     raise exceptions.CommandError(
                         _("The plan and the stack '{}' doesn't exist OR are "
@@ -425,7 +417,6 @@ class TripleOValidatorRun(command.Command):
                 validations_dir=constants.ANSIBLE_VALIDATION_DIR,
                 validation_name=parsed_args.validation_name,
                 extra_env_vars=extra_env_vars,
-                python_interpreter=parsed_args.python_interpreter,
                 quiet=quiet_mode)
         except RuntimeError as e:
             raise exceptions.CommandError(e)
